classdef CAcqSetup < handle & CCopyableObject
    %CACQSETUP   NiHu.Lab class for acquisition setup
    %   CACQSETUP Stores acquisition setup parameters, such a sampling
    %   frequency and number of samples.
    %
    % Example:
    % AS = CAcqSetup;
    % AS.FsRange = 1 : 10;
    % AS.nSamplesRange = 2.^(10:15);
    % AV = CAcqSetupView(gcf, AS);
    %
    % See also CAcqSetupView
    
    % Copyright (c) Peter Fiala 2014
    
    properties
        FsRange     % available sampling frequencies
        nSamplesRange % available number of samples
    end
    
    properties (SetObservable = true) % observed by listeners of CAcqSetupView
        Fs          % Sampling frequency
        nSamples    % Number of samples
    end
    
    properties (Dependent)
        T  % Acquisition time
    end
    
    methods
        function set.nSamples(obj, nsamples)
            % make sure nSamples is between limits
            [~, i] = min(abs(obj.nSamplesRange-nsamples));
            obj.nSamples = obj.nSamplesRange(i);
        end
        
        function set.Fs(obj, fs)
            [~, i] = min(abs(obj.FsRange-fs));
            obj.Fs = obj.FsRange(i);
        end
        
        function set.FsRange(obj, fsrange)
            obj.FsRange = fsrange;
            if isempty(obj.Fs)
                obj.Fs = obj.FsRange(1);
            end
        end
        
        function set.nSamplesRange(obj, nsamplesrange)
            obj.nSamplesRange = nsamplesrange;
            if isempty(obj.nSamples)
                obj.nSamples = obj.nSamplesRange(1);
            end
        end
        
        function t = get.T(obj)
            t = obj.nSamples / obj.Fs;
        end
    end
end
