classdef CAverageView < CGuiView & CBlockablePanel
    %CAVERAGEVIEW  NiHu.Lab panel for adjusting averaging parameters
    
    properties
        hTable  % the table where the data is displayed
        hAx     % the axis where the average counter is displayed
        hBar    % handle of the average counter bar
    end
    
    methods
        function obj = CAverageView(parent, hData)
            %CAVERAGEVIEW constructor
            
            obj = obj@CBlockablePanel(parent, 'AVERAGING_PANEL');
            obj = obj@CGuiView(hData, {'nAverage', 'isPre', 'nPre', 'nPost', 'iAver'});
            obj.InitObject();
            obj.refresh();
        end
        
        function refresh(obj)
            %REFRESH Called when the underlying data is modified
            
            D = {obj.hData.nPre, obj.hData.nAverage, obj.hData.nPost};
            set(obj.hTable, 'Data', D);
            set(obj.hTable, 'ColumnEditable', [obj.hData.isPre, true, obj.hData.isPre]);
            set(obj.hBar, 'ydata', obj.hData.iAver / (obj.hData.nPre + obj.hData.nAverage + obj.hData.nPost));
            if obj.hData.iAver > obj.hData.nPre + obj.hData.nAverage
                set(obj.hBar, 'FaceColor', 'red');
            elseif obj.hData.iAver > obj.hData.nPre
                set(obj.hBar, 'FaceColor', 'blue');
            else
                set(obj.hBar, 'FaceColor', 'green');
            end
        end
        
        function TableCallback(obj)
            %TABLECALLBACK Called when the GUI table is modified
            
            D = get(obj.hTable, 'Data');
            obj.hData.nPre = D{1};
            obj.hData.nAverage = D{2};
            obj.hData.nPost = D{3};
            obj.hData.reset();
        end
    end % of public methods
    
    methods (Access = private)
        function InitObject(obj)
            PreStr = cellstr(num2str((0:3)'))';
            PostStr = cellstr(num2str((0:3)'))';
            N = 500;
            a = unique(reshape(2.^(0:log2(N))' * 3.^(0:(log(N)/log(3))), [], 1));
            a = a(a<=N);
            AverStr = cellstr(num2str(a))';
            
            obj.hTable = uitable('Parent', obj.hPanel, ...
                'ColumnName', {'N Pre', 'N Aver.', 'N Post'}, ...
                'ColumnEditable', [true, true, true], ...
                'ColumnFormat', {PreStr, AverStr, PostStr}, ...
                'ColumnWidth', {67 67 67}, ...
                'RowName', [], ...
                'Data', {'1', '1', '1'}, ...
                'Position', [0 0, 100, 10], ...
                'CellEditCallback', @(src,event)TableCallback(obj));

            e = extent(obj.hTable);
            set(obj.hTable, 'Position', e);
            
            obj.hAx = axes('parent', obj.hPanel,...
                'units', 'pixels', 'position', [0 0 100, 10], ...
                'NextPlot', 'ReplaceChildren');
            obj.hBar = barh(obj.hAx, 0, 'FaceColor', 'blue');
            xlim(obj.hAx, [0 1]);
            set(obj.hAx, 'XTick', [], 'YTick', []);
            
            GuiLayout.ApplyLayout(obj.hPanel, {{obj.hTable, [0 0]};
                {obj.hAx, [-1 0]}});
        end
    end % of private methods
end % of classdef
