classdef CBabel < handle
    %CBABEL Gui language translation class

    properties (SetObservable = true)
        currentLanguage     % the current display language
    end
    
    properties (Access = protected)
        languages   % all of the stored languages
        texts       % cell string of all displayed texts in all languages
    end
    events
        languageChange % fired when language is changed
    end
    
    methods (Static = true)
        function obj = getInstance(varargin)
            %GETINSTANCE return current singleton instance
            
            persistent unique;
            if nargin > 0
                delete(unique);
            else
                if isempty(unique)
                    unique = CBabel(fullfile(fileparts(mfilename('fullpath')), 'data', 'babel.txt'));
                else
                end
            end
            obj = unique;
        end
        
        function delInstance
            %DELINSTANCE delete actual instance
            
            CBabel.getInstance('clear');
        end
    end % of static methods
    
    methods (Access = protected)
        function obj = CBabel(fname)
            %CBABEL constructor (protected)
            obj.languages = {};
            obj.texts = {};
            try
                fid = fopen(fname);
                t = textscan(fid, '%s', 'delimiter', '\n');
                fclose(fid);
                t = t{1};
                % remove leading and trailing spaces and empty lines
                t = strtrim(t(~ismember(t, '')));
                % remove comments
                t = t(~strncmp(t, '%', 1));
                k = 0;
                for iLine = 1 : length(t)
                    [a,b,~,d] = regexp(t{iLine}, '[A-Z_0-9]+');
                    if numel(a) == 1 && b(1) == length(t{iLine})
                        k = k + 1;
                        obj.texts(k,1) = d;
                    else
                        d = regexp(t{iLine}, '(?<language>\w+): (?<expression>.*)', 'names');
                        [b,n] = ismember(lower(d.language), obj.languages);
                        if b == false
                            obj.languages{end+1} = lower(d.language);
                            n = length(obj.languages);
                        end
                        obj.texts{k,n+1} = d.expression;
                    end
                end
                obj.currentLanguage = obj.languages{1};
            catch
            end
        end
    end % of protected methods
    
    methods
        function l = getLanguages(obj)
            %GETLANGUAGES return list of stored languages
            
            l = obj.languages;
        end
        
        function setCurrentLanguage(obj, lang)
            %SETCURRENTLANGUAGE Set the current language to a specified one
            if ~strcmpi(obj.currentLanguage, lang)
                obj.currentLanguage = lang;
                notify(obj, 'languageChange')
            end
        end
        
        function reTranslate(obj, f)
            %RETRANSLATE retranslate gui elements
            q = {
                'style', 'PushButton', 'String'
                'type', 'uiPanel', 'Title'
                'type', 'uitab', 'Title'
                'type', 'uimenu', 'Label'
                };
            for j = 1 : size(q,1)
                h = findobj(f, q{j,1}, q{j,2});
                for i = 1 : length(h)
                    t = get(h(i), 'Tag');
                    if ~isempty(t)
                        set(h(i), q{j,3}, obj.getText(t));
                    end
                end
            end
        end
        
        function t = getText(obj, textID)
            %GETTEXT Get a text by textID in the current language
            
            [b, i] = ismember(textID, obj.texts(:,1));
            if ~b
                t = textID;
            else
                n = find(ismember(obj.languages, obj.currentLanguage));
                t = obj.texts{i,n+1};
            end
        end
    end % of public methods
end % of classdef
