classdef CCalSelect < handle
    %CCALSELECT NiHu.Lab class for calibrator handling
    %
    % Example:
    %   CS = CCalSelect;
    %   CSV = CCalSelectView(f, CS);
    %
    % See also: CCalSelectView, CCalibrator
    
    properties (SetAccess = immutable)
        CalibDB     % handle to calibration database (array of CCalibrator)
    end
    
    properties (SetObservable)
        CalIndex    % index of selected calibrator in database
    end
    
    properties (Dependent)
        Calibrator  % handle of selected calibrator
    end
    
    methods
        function obj = CCalSelect
            obj.CalibDB = CCalSelect.ImportDB();
            obj.CalIndex = 1;
        end
        
        function c = get.Calibrator(obj)
            c = obj.CalibDB(obj.CalIndex);
        end
    end
    
    methods (Static, Access = private)
        function db = ImportDB
            % Import Calibrator Database
            name = fullfile(fileparts(mfilename('fullpath')), 'DataBase', 'Calibrators.csv');
            fid = fopen(name);
            if fid == -1
                error('NiHuLab:File', 'Cannot open file %s', name);
            end
            Cals = textscan(fid, '%s', 'delimiter', ',');
            fclose(fid);
            Cals = Cals{1};
            nFields = 6;
            Cals = reshape(Cals(nFields+1:end), nFields, [])';
            Cals(:,3) = num2cell(str2num(char(Cals(:,3))));
            Cals(:,5) = num2cell(str2num(char(Cals(:,5))));
            Cals(:,6) = num2cell(str2num(char(Cals(:,6))));
            nCal = size(Cals,1);
            db = CCalibrator.empty(1,0);
            for i = 1 : nCal
                cal = Cals(i,:);
                db(i,1) = CCalibrator(cal{:});
            end
        end
    end
end
