classdef CCalSelectView < CGuiView & CBlockablePanel
    %CCALSELECTVIEW  NiHu.Lab panel for calibrator selection
    %
    % Example:
    %   CS = CCalSelect;
    %   CSV = CCalSelectView(f, CS);
    %
    % See also: CGuiView, CBlockablePanel, CCalSelect, CCalibrator
    
    properties (Access = private)
        hTable      % table handle where the information is stored
    end
	
    methods
        function obj = CCalSelectView(parent, hData)
            obj = obj@CBlockablePanel(parent, 'CALSELECT_PANEL');
            obj = obj@CGuiView(hData, {'CalIndex'});
            obj.InitObject();
            obj.refresh();
        end
        
        function refresh(obj)
            %REFRESH Called when the GUI needs to be updated

            c = obj.hData.Calibrator;
            set(obj.hTable, 'Data', {c.Name, c.Level, c.Quantity.EU, c.Frequency});
        end
        
        function CalibTableCallback(obj)
            %CALIBTABLECALLBACK called when the calibrator select table is changed
            
            F = get(obj.hTable, 'ColumnFormat');
            D = get(obj.hTable, 'Data');
            [~, obj.hData.CalIndex] = ismember(D{1}, F{1});
        end
    end % of public methods

    methods (Access = private)
        function InitObject(obj)
            obj.hTable = uitable('Parent', obj.hPanel, ...
                'ColumnName', {'Name', 'Level', 'EU', 'Freq [Hz]'}, ...
                'ColumnEditable', [true, false, false, false], ...
                'ColumnFormat', {{obj.hData.CalibDB.Name}, 'numeric', 'char', 'numeric'}, ...
                'ColumnWidth', {90 35 25 50}, ...
                'RowName', [], ...
                'Data', {0, 0, 0, 0}, ...
                'CellEditCallback', @(src, event)CalibTableCallback(obj));
            e = extent(obj.hTable);
            set(obj.hTable, 'Position', e);
            l = {{obj.hTable, [0 0]}};
            GuiLayout.ApplyLayout(obj.hPanel, l);
        end
    end % of private methods
end % of classdef
