classdef CDistSignal < handle
    %CDISTSIGNAL  NiHu.Lab class for harmonic distortion signal selection
    
    properties (Access = private)
        data
    end
    
    properties (SetObservable = true)
        Amplitude
        Flim
        nFreq
    end
    
    methods
        function obj = CDistSignal()
            D = load(fullfile(fileparts(mfilename('fullpath')), 'data', 'NQ.mat'), 'data');
            obj.data = D.data;
            obj.Amplitude = 1;
            obj.Flim = [100 1000];
            obj.nFreq = 10;
        end
        
        function [Amp, Fvec, Nvec] = FreqsN(obj, fs, nSamples)
            p = round(log2(nSamples));
            N = obj.data{p}.N;              % selectable numsamples
            f = obj.data{p}.q ./ N * fs;    % selectable frequencies
            Fvec = 2.^(linspace(log2(obj.Flim(1)), log2(obj.Flim(2)), obj.nFreq));
            ind = unique(interp1(f, 1:length(f), Fvec, 'nearest', 'extrap'));
            Fvec = f(ind);
            Nvec = N(ind);
            Amp = obj.Amplitude;
        end
    end % of public methods
end % of classdef
