classdef CExcitation < handle & CCopyableObject
    %CEXCITATION  NiHu.Lab class for excitation signal generation

    properties (SetObservable = true)
        Types       % list of signal types
        Type        % Signal type
        Amplitude   % used for harmonic, MLS and sweeps
        SweepType   % used for Sweep (exp or lin)
        Flim        % used for sweeps
        Frequency   % used for harmonic
        Phase       % used for harmonic
        NoiseType   % used for Noises
        RMS         % used for noises
        NoiseColor  % used for Noises
        Fc          % used for noises
    end
    
    methods
        function obj = CExcitation(types)
            %CEXCITATION constructor
            
            if nargin < 1
                obj.Types = {'Harmonic', 'Sweep', 'Noise', 'MLS'};
            else
                obj.Types = types;
            end
            obj.Type = obj.Types{1};
            
            obj.Frequency = 1000;
            obj.Amplitude = 1;
            obj.Phase = 0;
            
            obj.RMS = 1;
            obj.NoiseType = 'uniform';
            obj.NoiseColor = 'white';
            obj.Fc = 100;
            
            obj.SweepType = 'exp';
            obj.Flim = [100 200];
        end
        
        function signal = GenerateSignal(obj, fs, nSamples)
            %GENERATESIGNAL generate an excitation signal
            
            switch lower(obj.Type)
                case 'harmonic'
                    F = obj.Frequency;
                    nPer = round(F*nSamples/fs); % number of periods
                    t = (0:nPer*fs/F-1)'/fs;
                    signal = obj.Amplitude *...
                        cos(2*pi*F*t + obj.Phase/180*pi);
                case 'sweep'
                    signal = obj.Amplitude * sweepsignal(obj.SweepType, obj.Flim, nSamples, fs);
                case 'noise'
                    [~, beta] = ismember(obj.NoiseColor, {'red', 'pink', 'white', 'blue', 'purple'});
                    signal = obj.RMS * ...
                        colornoise(fs, nSamples, beta-3, obj.NoiseType, obj.Fc);
                case 'mls'
                    signal = obj.Amplitude * mlssignal(round(log2(nSamples)));
            end
        end
    end % of public methods
end % of classdef
