classdef CGraphData < handle
    %CGRAPHDATA Plot window class
    
    properties (SetAccess = private)
        ChIDs = []  % Channel IDs (Physical Channel Number)
        ChNames     % Channel Names
        xEU         % Dimensions of x Axis
        yEU         % Dimensions of y Axis
        xQuant      % x Axis Label
        yQuant      % y Axis Label
        Colors
    end
    
    properties (SetObservable = true)
        xData   % x axis Data
        yData   % y axis Data
    end
    
    methods (Access = public)
        function obj = CGraphData
            %CGRAPHDATA constructor
            
            obj.UpdateChannels(0, {''}, '', '', {''}, {''}, []);
            obj.xData = 0;
            obj.yData = nan(1, 1);
        end
        
        function UpdateChannels(obj, ChIDs, ChNames, xQuant, xEU, yQuant, yEU, colors)
            %UPDATECHANNELS called when the channel setup is changed

            obj.ChIDs = ChIDs;
            obj.ChNames = ChNames;
            obj.xQuant = xQuant;
            obj.xEU = xEU;
            nCh = length(ChIDs);
            if iscell(yQuant)
                obj.yQuant = yQuant;
            else
                obj.yQuant = mat2cell(repmat(yQuant,nCh,1),ones(nCh,1));
            end
            if iscell(yEU)
                obj.yEU = yEU;
            else
                obj.yEU = mat2cell(repmat(yEU,nCh,1),ones(nCh,1));
            end
            obj.Colors = colors;
            obj.xData = 0;
            obj.yData = nan(1, nCh);
        end
        
        function UpdateData(obj, xData, yData)
            %UPDATEDATA called when the data to display is changed

            obj.xData = xData;
            obj.yData = yData;
        end
    end
end