classdef CReferenceSelect < handle
    %CREFERENCESELECT Refence selection for transfer function measurement
    % Created by Ruster, March 2012
    properties (SetObservable)
        IsFileChosen    % Is file chosen?
        IsActive        % Is reference activated?
        FileName        % Name of reference file
        Directory       % Directory of reference data
        ChInd           % Channel index of reference data
    end
    
    % The data that is used as reference
    properties (SetAccess = private, GetAccess = private)
        ReferenceData
    end
    
    methods
        % Constructor
        function obj = CReferenceSelect()
            %obj.FileName = CBabel.getInstance().getText('UNTITLED');
            obj.FileName = 'No file selected';
            obj.Directory = pwd;
            obj.IsFileChosen = false;
            obj.IsActive = false;
        end % of constructor
        
        % Toggle Active of /off
        function ToggleActive(obj)
            % TODO: fill this (debug)
            disp('CReferenceSelect: ToggleActive');
            obj.IsActive = ~obj.IsActive;
        end % of ToggleActive method
        
        function result = LoadFile(obj, pathname, filename)
            % TODO: fill this (debug)
            disp('CReferenceSelect: LoadFile');
            fname = fullfile(pathname, filename);
            obj.ReferenceData = importdata(fname);
            % TODO: Add error handling here
            % File has been selected
            obj.FileName = filename;
            obj.Directory = pathname;
            obj.IsFileChosen = true;
            obj.IsActive = false;
            obj.ChInd = 1;
            % Return with success
            result = 0;
        end
        
        function result = ClearFile(obj)
            % TODO: this is debug only
            disp('CReferenceSelect: ClearFile');
            obj.ReferenceData = [];
            obj.FileName = 'No file selected';
            obj.Directory = pwd;
            obj.IsFileChosen = false;
            obj.IsActive = false;
            result = 0;
        end

        % ChannelNames - returns names of channels
        function names = ChannelNames(obj)
            names = {obj.ReferenceData.Channels.Name};
            names = names(cell2mat({obj.ReferenceData.Channels.isSelected}));
        end
        
        % Select channels
        function SelectChannel(obj, ind)
            % TODO: this is debug only
            fprintf('CReferenceSelect: ChannelSelect(%d)\n', ind);
            obj.ChInd = ind;
        end
        
        function [H, C] = GetReferenceFRF(obj, fs, ns)
            % TODO: this is debug only
            fprintf('CReferenceSelect: GetReferenceFRF(%d, %d)\n', fs, ns);
            fs0 = obj.ReferenceData.AcqSetup.Fs;
            ns0 = obj.ReferenceData.AcqSetup.nSamples;
            if strcmp(obj.ReferenceData.Excitation.Type, 'MLS')
                ns0 = 2^(round(log2(ns0))) - 1;
            end
            H = obj.ReferenceData.FrequencyResponseFunction(:, obj.ChInd);
            C = obj.ReferenceData.Coherence(:, obj.ChInd); 
            % If number of samples or fs does not match
            if (fs ~= fs0) || (ns ~= ns0)
                f = linspace(0, fs/2, floor(ns/2)+1).';
                f0 = linspace(0, fs0/2, floor(ns0/2)+1).';
                H = interp1(f0, H, f);
                C = interp1(f0, C, f);
            end
        end % of GetRereferenceFRF method
    end % of methods
end % of CReferenceSelect class
