classdef CStreamViewer < CUiTab
    %CSTREAMVIEWER Nihu.Lab module for stream display
    
    properties (Access = private)
        GraphData
        GraphDataView
    end
    
    methods
        function obj = CStreamViewer(ParentGroup)
            obj = obj@CUiTab(ParentGroup, 'STREAMVIEWER_MODULE');
            obj.GraphData = CGraphData;
            obj.InitFigure();
        end
        
        function PlayBack(obj)
            XL = get(obj.hAx, 'xlim');
            x = get(obj.hLine(1), 'xData');
            ind = x > XL(1) & x < XL(2);
            soundsc(obj.Data(ind,get(obj.hSel, 'value')), obj.Fs);
        end
        
        function ButOpenCallback(obj, edFile)
            [FileName, PathName] = uigetfile('*.dat');
            if FileName == 0
                return;
            end
            try
                [H, D] = LoadStream(fullfile(PathName, FileName));
            catch ME
                errordlg(sprintf('There was an error opening the file\n%s\n%s', FileName, ME.message), 'File Open Error', 'modal')
                return;
            end
            set(edFile, 'String', FileName);
            obj.RefreshData(H, D);
        end
        
        function RefreshData(obj, H, D)
            obj.GraphData.UpdateChannels(cell2mat({H.ChSetup.PhysChNr}),...
                {H.ChSetup.Name}, 'Time', 's', H.ChSetup.getQuantText(), H.ChSetup.getEUText());
            obj.GraphData.UpdateData((0:size(D,1)-1)'/H.AcqSetup.Fs, D);
            obj.GraphDataView.UpdateChannels();
        end
    end
    
    methods (Access = private)
        function InitFigure(obj)
            obj.GraphDataView = CGraphDataView(obj.hContainer, obj.GraphData, 'Stream Data');
            
            panFile = CPanel(obj.hContainer, 'Select File');
            edFile = uicontrol('parent', panFile.hPanel, 'Style', 'edit', 'Enable', 'inactive', ...
                'String', '');
            im = importdata([matlabroot, '/toolbox/matlab/icons/foldericon.gif']);
            butOpen = uicontrol('Parent', panFile.hPanel, 'Style', 'pushButton',...
                'String', '',...
                'CData', ind2rgb(im.cdata, im.colormap), ...
                'ToolTipStr', 'Select Directory', ...
                'Callback', @(src,event)ButOpenCallback(obj, edFile), ...
                'Position', [0, 0, CSetupClass.itemHeight, CSetupClass.itemHeight]);
            GuiLayout.ApplyLayout(panFile.hPanel, {{edFile, [-1 0]}, {butOpen, [0 0]}});
            
            GuiLayout.ApplyLayout(obj.hContainer, {{panFile.hPanel, [150 0]}, {obj.GraphDataView.hPanel, [-1 -1]}});
        end
    end
    
    methods
        function show(obj)
            %SHOW function called each time before the module is opened
            obj.GraphDataView.unblock();
        end
        
        function hide(obj)
            %SHOW function called each time before the module is closed
            
            obj.GraphDataView.block();
        end
    end
end
